/* Compiler: ECL 26.3.27                                                      */
/* Source: /build/ecl/src/ecl-26.3.27/src/cmp/cmprefs.lsp                     */
#include <ecl/ecl-cmp.h>
#include "cmp/cmprefs.eclh"
/* function definition for MAKE-REF                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3123make_ref(cl_narg narg, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1;
  cl_object v2;
  cl_object v3;
  cl_object v4;
  cl_object v5;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  {
   cl_object keyvars[10];
   cl_parse_key(args,5,L3123make_refkeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v1 = keyvars[0];
   if (Null(keyvars[6])) {
    v2 = ecl_make_int8_t(0);
   } else {
    v2 = keyvars[1];
   }
   v3 = keyvars[2];
   v4 = keyvars[3];
   v5 = keyvars[4];
  }
  if (ECL_FIXNUMP(v2)) {
   goto L2;
  }
  si_structure_type_error(v2, ECL_SYM("FIXNUM",374), VV[1], VV[1]);
L2:;
  value0 = si_make_structure(6, VV[7], v1, v2, v3, v4, v5);
  return value0;
 }
}
/* local function LAMBDA2                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3124__lambda2(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(4), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(4));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3124__lambda2_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[11]);
 {
  return LC3124__lambda2(v5, v6si__x);
 }
}
/* local function LAMBDA7                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3125__lambda7(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(3), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(3));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3125__lambda7_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[13]);
 {
  return LC3125__lambda7(v5, v6si__x);
 }
}
/* local function LAMBDA12                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3126__lambda12(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(2), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(2));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3126__lambda12_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[15]);
 {
  return LC3126__lambda12(v5, v6si__x);
 }
}
/* local function LAMBDA17                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3127__lambda17(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(1), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(1));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3127__lambda17_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[17]);
 {
  return LC3127__lambda17(v5, v6si__x);
 }
}
/* local function LAMBDA22                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3128__lambda22(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(0), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(0));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3128__lambda22_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[19]);
 {
  return LC3128__lambda22(v5, v6si__x);
 }
}
/* function definition for PRINT-REF                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3129print_ref(cl_object v1ref_object, cl_object v2stream)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3name;
  v3name = (cl_env_copy->function=ecl_fdefinition(VV[18]))->cfun.entry(1, v1ref_object) /*  REF-NAME */;
  if (Null(v3name)){
   goto L3;
  }
  T0 = cl_type_of(v1ref_object);
  value0 = cl_format(4, v2stream, VV[20], T0, v3name);
  return value0;
L3:;
  T0 = cl_type_of(v1ref_object);
  value0 = cl_format(3, v2stream, VV[21], T0);
  return value0;
 }
}
static cl_object L3129print_ref_va(cl_narg narg, cl_object v4ref_object, cl_object v5stream, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[3]);
 {
  return L3129print_ref(v4ref_object, v5stream);
 }
}
/* local function LAMBDA30                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3130__lambda30(cl_object v1, cl_object v2)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  v3 = ecl_cdr(v1);
  if (Null(v3)){
   goto L3;
  }
  si_dm_too_many_arguments(v1);
L3:;
  value0 = VV[26];
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC3130__lambda30_va(cl_narg narg, cl_object v4, cl_object v5, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[24]);
 {
  return LC3130__lambda30(v4, v5);
 }
}
/* function definition for %MAKE-VAR                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3131_make_var(cl_narg narg, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1;
  cl_object v2;
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6;
  cl_object v7;
  cl_object v8;
  cl_object v9;
  cl_object v10;
  cl_object v11;
  cl_object v12;
  cl_object v13;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  {
   cl_object keyvars[26];
   cl_parse_key(args,13,L3131_make_varkeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v1 = keyvars[0];
   if (Null(keyvars[14])) {
    v2 = ecl_make_int8_t(0);
   } else {
    v2 = keyvars[1];
   }
   v3 = keyvars[2];
   v4 = keyvars[3];
   v5 = keyvars[4];
   v6 = keyvars[5];
   v7 = keyvars[6];
   if (Null(keyvars[20])) {
    v8 = ecl_cmp_symbol_value(cl_env_copy,VV[31]);
   } else {
    v8 = keyvars[7];
   }
   v9 = keyvars[8];
   v10 = keyvars[9];
   if (Null(keyvars[23])) {
    v11 = VV[23];
   } else {
    v11 = keyvars[10];
   }
   if (Null(keyvars[24])) {
    v12 = ECL_T;
   } else {
    v12 = keyvars[11];
   }
   v13 = keyvars[12];
  }
  if (ECL_FIXNUMP(v2)) {
   goto L5;
  }
  si_structure_type_error(v2, ECL_SYM("FIXNUM",374), VV[27], VV[1]);
L5:;
  value0 = si_make_structure(14, VV[33], v1, v2, v3, v4, v5, v6, v7, v8, v9, v10, v11, v12, v13);
  return value0;
 }
}
/* local function LAMBDA34                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3132__lambda34(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[27]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(12), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[27]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(12));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3132__lambda34_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[36]);
 {
  return LC3132__lambda34(v5, v6si__x);
 }
}
/* local function LAMBDA39                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3133__lambda39(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[27]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(11), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[27]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(11));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3133__lambda39_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[38]);
 {
  return LC3133__lambda39(v5, v6si__x);
 }
}
/* local function LAMBDA44                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3134__lambda44(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[27]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(10), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[27]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(10));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3134__lambda44_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[40]);
 {
  return LC3134__lambda44(v5, v6si__x);
 }
}
/* local function LAMBDA49                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3135__lambda49(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[27]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(9), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[27]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(9));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3135__lambda49_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[42]);
 {
  return LC3135__lambda49(v5, v6si__x);
 }
}
/* local function LAMBDA54                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3136__lambda54(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[27]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(8), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[27]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(8));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3136__lambda54_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[44]);
 {
  return LC3136__lambda54(v5, v6si__x);
 }
}
/* local function LAMBDA59                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3137__lambda59(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[27]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(7), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[27]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(7));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3137__lambda59_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[46]);
 {
  return LC3137__lambda59(v5, v6si__x);
 }
}
/* local function LAMBDA64                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3138__lambda64(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[27]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(6), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[27]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(6));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3138__lambda64_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[48]);
 {
  return LC3138__lambda64(v5, v6si__x);
 }
}
/* local function LAMBDA69                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3139__lambda69(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[27]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(5), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[27]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(5));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3139__lambda69_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[50]);
 {
  return LC3139__lambda69(v5, v6si__x);
 }
}
/* local function LAMBDA74                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3140__lambda74(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[27]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(4), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[27]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(4));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3140__lambda74_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[52]);
 {
  return LC3140__lambda74(v5, v6si__x);
 }
}
/* local function LAMBDA79                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3141__lambda79(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[27]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(3), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[27]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(3));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3141__lambda79_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[54]);
 {
  return LC3141__lambda79(v5, v6si__x);
 }
}
/* local function LAMBDA84                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3142__lambda84(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[27]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(2), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[27]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(2));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3142__lambda84_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[56]);
 {
  return LC3142__lambda84(v5, v6si__x);
 }
}
/* local function LAMBDA89                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3143__lambda89(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[27]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(1), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[27]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(1));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3143__lambda89_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[58]);
 {
  return LC3143__lambda89(v5, v6si__x);
 }
}
/* local function LAMBDA94                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3144__lambda94(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[27]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(0), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[27]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(0));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3144__lambda94_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[60]);
 {
  return LC3144__lambda94(v5, v6si__x);
 }
}
/* function definition for PRINT-VAR                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3145print_var(cl_object v1var_object, cl_object v2stream)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[59]))->cfun.entry(1, v1var_object) /*  VAR-NAME */;
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[47]))->cfun.entry(1, v1var_object) /*  VAR-KIND */;
 value0 = cl_format(4, v2stream, VV[61], T0, T1);
 return value0;
}
static cl_object L3145print_var_va(cl_narg narg, cl_object v3var_object, cl_object v4stream, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[29]);
 {
  return L3145print_var(v3var_object, v4stream);
 }
}
/* function definition for MAKE-FUN                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3146make_fun(cl_narg narg, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1;
  cl_object v2;
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6;
  cl_object v7;
  cl_object v8;
  cl_object v9;
  cl_object v10;
  cl_object v11;
  cl_object v12;
  cl_object v13;
  cl_object v14;
  cl_object v15;
  cl_object v16;
  cl_object v17;
  cl_object v18;
  cl_object v19;
  cl_object v20;
  cl_object v21;
  cl_object v22;
  cl_object v23;
  cl_object v24;
  cl_object v25;
  cl_object v26;
  cl_object v27;
  cl_object v28;
  cl_object v29;
  cl_object v30;
  cl_object v31;
  cl_object v32;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  {
   cl_object keyvars[64];
   cl_parse_key(args,32,L3146make_funkeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v1 = keyvars[0];
   if (Null(keyvars[33])) {
    v2 = ecl_make_int8_t(0);
   } else {
    v2 = keyvars[1];
   }
   v3 = keyvars[2];
   v4 = keyvars[3];
   v5 = keyvars[4];
   v6 = keyvars[5];
   if (Null(keyvars[38])) {
    v7 = VV[66];
   } else {
    v7 = keyvars[6];
   }
   if (Null(keyvars[39])) {
    v8 = ecl_make_int8_t(0);
   } else {
    v8 = keyvars[7];
   }
   if (Null(keyvars[40])) {
    v9 = ecl_make_int8_t(0);
   } else {
    v9 = keyvars[8];
   }
   v10 = keyvars[9];
   v11 = keyvars[10];
   v12 = keyvars[11];
   v13 = keyvars[12];
   v14 = keyvars[13];
   v15 = keyvars[14];
   v16 = keyvars[15];
   v17 = keyvars[16];
   if (Null(keyvars[49])) {
    v18 = ecl_make_int8_t(0);
   } else {
    v18 = keyvars[17];
   }
   if (Null(keyvars[50])) {
    v19 = ecl_make_fixnum(65536);
   } else {
    v19 = keyvars[18];
   }
   if (Null(keyvars[51])) {
    v20 = VV[67];
   } else {
    v20 = keyvars[19];
   }
   if (Null(keyvars[52])) {
    v21 = ecl_cmp_symbol_value(cl_env_copy,VV[31]);
   } else {
    v21 = keyvars[20];
   }
   v22 = keyvars[21];
   v23 = keyvars[22];
   v24 = keyvars[23];
   v25 = keyvars[24];
   v26 = keyvars[25];
   if (Null(keyvars[58])) {
    v27 = ecl_car(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*SOURCE-LOCATION*",1210)));
   } else {
    v27 = keyvars[26];
   }
   if (Null(keyvars[59])) {
    value0 = ecl_cdr(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*SOURCE-LOCATION*",1210)));
    if (value0!=ECL_NIL) {
     goto L12;
    }
    v28 = ecl_cmp_symbol_value(cl_env_copy,VV[68]);
    goto L10;
L12:;
    v28 = value0;
    goto L10;
L10:;
   } else {
    v28 = keyvars[27];
   }
   if (Null(keyvars[60])) {
    v29 = (cl_env_copy->function=ecl_fdefinition(VV[69]))->cfun.entry(0) /*  CMP-ENV-COPY */;
   } else {
    v29 = keyvars[28];
   }
   v30 = keyvars[29];
   v31 = keyvars[30];
   v32 = keyvars[31];
  }
  if (ECL_FIXNUMP(v2)) {
   goto L15;
  }
  si_structure_type_error(v2, ECL_SYM("FIXNUM",374), VV[63], VV[1]);
L15:;
  value0 = si_make_structure(33, VV[71], v1, v2, v3, v4, v5, v6, v7, v8, v9, v10, v11, v12, v13, v14, v15, v16, v17, v18, v19, v20, v21, v22, v23, v24, v25, v26, v27, v28, v29, v30, v31, v32);
  return value0;
 }
}
/* local function LAMBDA101                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3147__lambda101(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(31), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(31));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3147__lambda101_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[74]);
 {
  return LC3147__lambda101(v5, v6si__x);
 }
}
/* local function LAMBDA106                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3148__lambda106(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(30), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(30));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3148__lambda106_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[76]);
 {
  return LC3148__lambda106(v5, v6si__x);
 }
}
/* local function LAMBDA111                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3149__lambda111(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(29), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(29));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3149__lambda111_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[78]);
 {
  return LC3149__lambda111(v5, v6si__x);
 }
}
/* local function LAMBDA116                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3150__lambda116(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(28), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(28));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3150__lambda116_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[80]);
 {
  return LC3150__lambda116(v5, v6si__x);
 }
}
/* local function LAMBDA121                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3151__lambda121(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(27), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(27));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3151__lambda121_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[82]);
 {
  return LC3151__lambda121(v5, v6si__x);
 }
}
/* local function LAMBDA126                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3152__lambda126(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(26), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(26));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3152__lambda126_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[84]);
 {
  return LC3152__lambda126(v5, v6si__x);
 }
}
/* local function LAMBDA131                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3153__lambda131(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(25), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(25));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3153__lambda131_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[86]);
 {
  return LC3153__lambda131(v5, v6si__x);
 }
}
/* local function LAMBDA136                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3154__lambda136(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(24), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(24));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3154__lambda136_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[88]);
 {
  return LC3154__lambda136(v5, v6si__x);
 }
}
/* local function LAMBDA141                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3155__lambda141(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(23), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(23));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3155__lambda141_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[90]);
 {
  return LC3155__lambda141(v5, v6si__x);
 }
}
/* local function LAMBDA146                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3156__lambda146(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(22), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(22));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3156__lambda146_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[92]);
 {
  return LC3156__lambda146(v5, v6si__x);
 }
}
/* local function LAMBDA151                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3157__lambda151(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(21), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(21));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3157__lambda151_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[94]);
 {
  return LC3157__lambda151(v5, v6si__x);
 }
}
/* local function LAMBDA156                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3158__lambda156(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(20), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(20));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3158__lambda156_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[96]);
 {
  return LC3158__lambda156(v5, v6si__x);
 }
}
/* local function LAMBDA161                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3159__lambda161(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(19), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(19));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3159__lambda161_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[98]);
 {
  return LC3159__lambda161(v5, v6si__x);
 }
}
/* local function LAMBDA166                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3160__lambda166(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(18), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(18));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3160__lambda166_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[100]);
 {
  return LC3160__lambda166(v5, v6si__x);
 }
}
/* local function LAMBDA171                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3161__lambda171(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(17), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(17));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3161__lambda171_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[102]);
 {
  return LC3161__lambda171(v5, v6si__x);
 }
}
/* local function LAMBDA176                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3162__lambda176(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(16), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(16));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3162__lambda176_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[104]);
 {
  return LC3162__lambda176(v5, v6si__x);
 }
}
/* local function LAMBDA181                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3163__lambda181(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(15), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(15));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3163__lambda181_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[106]);
 {
  return LC3163__lambda181(v5, v6si__x);
 }
}
/* local function LAMBDA186                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3164__lambda186(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(14), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(14));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3164__lambda186_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[108]);
 {
  return LC3164__lambda186(v5, v6si__x);
 }
}
/* local function LAMBDA191                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3165__lambda191(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(13), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(13));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3165__lambda191_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[110]);
 {
  return LC3165__lambda191(v5, v6si__x);
 }
}
/* local function LAMBDA196                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3166__lambda196(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(12), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(12));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3166__lambda196_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[112]);
 {
  return LC3166__lambda196(v5, v6si__x);
 }
}
/* local function LAMBDA201                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3167__lambda201(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(11), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(11));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3167__lambda201_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[114]);
 {
  return LC3167__lambda201(v5, v6si__x);
 }
}
/* local function LAMBDA206                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3168__lambda206(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(10), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(10));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3168__lambda206_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[116]);
 {
  return LC3168__lambda206(v5, v6si__x);
 }
}
/* local function LAMBDA211                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3169__lambda211(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(9), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(9));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3169__lambda211_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[118]);
 {
  return LC3169__lambda211(v5, v6si__x);
 }
}
/* local function LAMBDA216                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3170__lambda216(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(8), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(8));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3170__lambda216_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[120]);
 {
  return LC3170__lambda216(v5, v6si__x);
 }
}
/* local function LAMBDA221                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3171__lambda221(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(7), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(7));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3171__lambda221_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[122]);
 {
  return LC3171__lambda221(v5, v6si__x);
 }
}
/* local function LAMBDA226                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3172__lambda226(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(6), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(6));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3172__lambda226_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[124]);
 {
  return LC3172__lambda226(v5, v6si__x);
 }
}
/* local function LAMBDA231                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3173__lambda231(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(5), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(5));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3173__lambda231_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[126]);
 {
  return LC3173__lambda231(v5, v6si__x);
 }
}
/* local function LAMBDA236                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3174__lambda236(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(4), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(4));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3174__lambda236_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[128]);
 {
  return LC3174__lambda236(v5, v6si__x);
 }
}
/* local function LAMBDA241                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3175__lambda241(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(3), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(3));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3175__lambda241_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[130]);
 {
  return LC3175__lambda241(v5, v6si__x);
 }
}
/* local function LAMBDA246                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3176__lambda246(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(2), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(2));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3176__lambda246_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[132]);
 {
  return LC3176__lambda246(v5, v6si__x);
 }
}
/* local function LAMBDA251                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3177__lambda251(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(1), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(1));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3177__lambda251_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[134]);
 {
  return LC3177__lambda251(v5, v6si__x);
 }
}
/* local function LAMBDA256                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3178__lambda256(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(0), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[63]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(0));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3178__lambda256_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[136]);
 {
  return LC3178__lambda256(v5, v6si__x);
 }
}
/* function definition for MAKE-BLK                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3179make_blk(cl_narg narg, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1;
  cl_object v2;
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6;
  cl_object v7;
  cl_object v8;
  cl_object v9;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  {
   cl_object keyvars[18];
   cl_parse_key(args,9,L3179make_blkkeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v1 = keyvars[0];
   if (Null(keyvars[10])) {
    v2 = ecl_make_int8_t(0);
   } else {
    v2 = keyvars[1];
   }
   v3 = keyvars[2];
   v4 = keyvars[3];
   v5 = keyvars[4];
   v6 = keyvars[5];
   v7 = keyvars[6];
   v8 = keyvars[7];
   if (Null(keyvars[17])) {
    v9 = VV[67];
   } else {
    v9 = keyvars[8];
   }
  }
  if (ECL_FIXNUMP(v2)) {
   goto L3;
  }
  si_structure_type_error(v2, ECL_SYM("FIXNUM",374), VV[137], VV[1]);
L3:;
  value0 = si_make_structure(10, VV[141], v1, v2, v3, v4, v5, v6, v7, v8, v9);
  return value0;
 }
}
/* local function LAMBDA262                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3180__lambda262(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[137]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(8), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[137]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(8));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3180__lambda262_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[144]);
 {
  return LC3180__lambda262(v5, v6si__x);
 }
}
/* local function LAMBDA267                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3181__lambda267(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[137]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(7), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[137]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(7));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3181__lambda267_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[146]);
 {
  return LC3181__lambda267(v5, v6si__x);
 }
}
/* local function LAMBDA272                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3182__lambda272(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[137]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(6), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[137]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(6));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3182__lambda272_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[148]);
 {
  return LC3182__lambda272(v5, v6si__x);
 }
}
/* local function LAMBDA277                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3183__lambda277(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[137]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(5), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[137]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(5));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3183__lambda277_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[150]);
 {
  return LC3183__lambda277(v5, v6si__x);
 }
}
/* local function LAMBDA282                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3184__lambda282(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[137]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(4), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[137]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(4));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3184__lambda282_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[152]);
 {
  return LC3184__lambda282(v5, v6si__x);
 }
}
/* local function LAMBDA287                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3185__lambda287(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[137]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(3), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[137]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(3));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3185__lambda287_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[154]);
 {
  return LC3185__lambda287(v5, v6si__x);
 }
}
/* local function LAMBDA292                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3186__lambda292(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[137]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(2), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[137]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(2));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3186__lambda292_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[156]);
 {
  return LC3186__lambda292(v5, v6si__x);
 }
}
/* local function LAMBDA297                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3187__lambda297(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[137]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(1), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[137]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(1));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3187__lambda297_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[158]);
 {
  return LC3187__lambda297(v5, v6si__x);
 }
}
/* local function LAMBDA302                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3188__lambda302(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[137]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(0), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[137]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(0));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3188__lambda302_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[160]);
 {
  return LC3188__lambda302(v5, v6si__x);
 }
}
/* function definition for MAKE-TAG                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3189make_tag(cl_narg narg, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1;
  cl_object v2;
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6;
  cl_object v7;
  cl_object v8;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  {
   cl_object keyvars[16];
   cl_parse_key(args,8,L3189make_tagkeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v1 = keyvars[0];
   if (Null(keyvars[9])) {
    v2 = ecl_make_int8_t(0);
   } else {
    v2 = keyvars[1];
   }
   v3 = keyvars[2];
   v4 = keyvars[3];
   v5 = keyvars[4];
   v6 = keyvars[5];
   v7 = keyvars[6];
   v8 = keyvars[7];
  }
  if (ECL_FIXNUMP(v2)) {
   goto L2;
  }
  si_structure_type_error(v2, ECL_SYM("FIXNUM",374), VV[161], VV[1]);
L2:;
  value0 = si_make_structure(9, VV[165], v1, v2, v3, v4, v5, v6, v7, v8);
  return value0;
 }
}
/* local function LAMBDA308                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3190__lambda308(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[161]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(7), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[161]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(7));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3190__lambda308_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[168]);
 {
  return LC3190__lambda308(v5, v6si__x);
 }
}
/* local function LAMBDA313                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3191__lambda313(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[161]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(6), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[161]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(6));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3191__lambda313_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[170]);
 {
  return LC3191__lambda313(v5, v6si__x);
 }
}
/* local function LAMBDA318                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3192__lambda318(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[161]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(5), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[161]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(5));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3192__lambda318_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[172]);
 {
  return LC3192__lambda318(v5, v6si__x);
 }
}
/* local function LAMBDA323                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3193__lambda323(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[161]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(4), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[161]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(4));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3193__lambda323_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[174]);
 {
  return LC3193__lambda323(v5, v6si__x);
 }
}
/* local function LAMBDA328                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3194__lambda328(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[161]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(3), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[161]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(3));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3194__lambda328_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[176]);
 {
  return LC3194__lambda328(v5, v6si__x);
 }
}
/* local function LAMBDA333                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3195__lambda333(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[161]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(2), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[161]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(2));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3195__lambda333_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[178]);
 {
  return LC3195__lambda333(v5, v6si__x);
 }
}
/* local function LAMBDA338                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3196__lambda338(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[161]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(1), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[161]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(1));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3196__lambda338_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[180]);
 {
  return LC3196__lambda338(v5, v6si__x);
 }
}
/* local function LAMBDA343                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3197__lambda343(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[161]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(0), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[161]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(0));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3197__lambda343_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[182]);
 {
  return LC3197__lambda343(v5, v6si__x);
 }
}
#include "cmp/cmprefs.data"
#ifdef __cplusplus
extern "C"
#endif

ECL_DLLEXPORT void _eclDI881bnEpwhn9_BYO0M881(cl_object flag)
{
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_object *VVtemp;
 if (flag != OBJNULL){
 Cblock = flag;
 #ifndef ECL_DYNAMIC_VV
 flag->cblock.data = VV;
 #endif
 flag->cblock.data_size = VM;
 flag->cblock.temp_data_size = VMtemp;
 flag->cblock.data_text = compiler_data_text;
 flag->cblock.cfuns_size = compiler_cfuns_size;
 flag->cblock.cfuns = compiler_cfuns;
 flag->cblock.source = ecl_make_constant_base_string("SRC:CMP;CMPREFS.LSP.NEWEST",-1);
 return;}
 #ifdef ECL_DYNAMIC_VV
 VV = Cblock->cblock.data;
 #endif
 Cblock->cblock.data_text = (const cl_object *)"@EcLtAg:_eclDI881bnEpwhn9_BYO0M881@";
 VVtemp = Cblock->cblock.temp_data;
 ECL_DEFINE_SETF_FUNCTIONS
 {
  cl_object T0;
  cl_object volatile env0 = ECL_NIL;
/* MAKE-LOAD-FORMs                                                            */
/* TOP-LEVEL-FORMs                                                            */
  si_select_package(_ecl_static_0);
  si_define_structure(VV[1], _ecl_static_1, ECL_NIL, ECL_NIL, VVtemp[0], VVtemp[1], VV[2], ECL_NIL, ECL_NIL, VV[3], VVtemp[2], ecl_make_int8_t(5), ECL_NIL, ECL_NIL, VV[4]);
  VV[7]=cl_find_class(1, VV[1]);
  ecl_cmp_defun(VV[183]);                         /*  MAKE-REF                */
  {
   cl_object v1package;
   v1package = cl_symbol_package(VV[9]);
   if (Null(v1package)){
    goto L9;
   }
   if (Null(si_package_locked_p(v1package))){
    goto L9;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L9;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[5], ECL_SYM("PACKAGE",1321), v1package);
  }
L9:;
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC3124__lambda2_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  si_put_sysprop(VV[9], VV[10], T0);
  {
   cl_object v2package;
   v2package = cl_symbol_package(VV[12]);
   if (Null(v2package)){
    goto L17;
   }
   if (Null(si_package_locked_p(v2package))){
    goto L17;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L17;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[6], ECL_SYM("PACKAGE",1321), v2package);
  }
L17:;
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC3125__lambda7_va,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  si_put_sysprop(VV[12], VV[10], T0);
  {
   cl_object v3package;
   v3package = cl_symbol_package(VV[14]);
   if (Null(v3package)){
    goto L25;
   }
   if (Null(si_package_locked_p(v3package))){
    goto L25;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L25;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[7], ECL_SYM("PACKAGE",1321), v3package);
  }
L25:;
  {
   cl_object volatile v4;
   v4 = ecl_make_cfun_va((cl_objectfn)LC3126__lambda12_va,ECL_NIL,Cblock,2);
   T0 = v4;
  }
  si_put_sysprop(VV[14], VV[10], T0);
  {
   cl_object v4package;
   v4package = cl_symbol_package(VV[16]);
   if (Null(v4package)){
    goto L33;
   }
   if (Null(si_package_locked_p(v4package))){
    goto L33;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L33;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[8], ECL_SYM("PACKAGE",1321), v4package);
  }
L33:;
  {
   cl_object volatile v5;
   v5 = ecl_make_cfun_va((cl_objectfn)LC3127__lambda17_va,ECL_NIL,Cblock,2);
   T0 = v5;
  }
  si_put_sysprop(VV[16], VV[10], T0);
  {
   cl_object v5package;
   v5package = cl_symbol_package(VV[18]);
   if (Null(v5package)){
    goto L41;
   }
   if (Null(si_package_locked_p(v5package))){
    goto L41;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L41;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[9], ECL_SYM("PACKAGE",1321), v5package);
  }
L41:;
  {
   cl_object volatile v6;
   v6 = ecl_make_cfun_va((cl_objectfn)LC3128__lambda22_va,ECL_NIL,Cblock,2);
   T0 = v6;
  }
  si_put_sysprop(VV[18], VV[10], T0);
  ecl_cmp_defun(VV[184]);                         /*  PRINT-REF               */
  {
   cl_object volatile v6;
   v6 = ecl_make_cfun_va((cl_objectfn)LC3130__lambda30_va,ECL_NIL,Cblock,2);
   T0 = v6;
  }
  si_do_deftype(3, VV[23], VVtemp[10], T0);
  si_define_structure(VV[27], _ecl_static_2, ECL_NIL, ECL_NIL, VVtemp[11], VVtemp[12], VV[28], VV[1], ECL_NIL, VV[29], VVtemp[13], ecl_make_int8_t(13), ECL_NIL, ECL_NIL, VV[30]);
  VV[33]=cl_find_class(1, VV[27]);
  ecl_cmp_defun(VV[185]);                         /*  %MAKE-VAR               */
  {
   cl_object v6package;
   v6package = cl_symbol_package(VV[35]);
   if (Null(v6package)){
    goto L62;
   }
   if (Null(si_package_locked_p(v6package))){
    goto L62;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L62;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[14], ECL_SYM("PACKAGE",1321), v6package);
  }
L62:;
  {
   cl_object volatile v7;
   v7 = ecl_make_cfun_va((cl_objectfn)LC3132__lambda34_va,ECL_NIL,Cblock,2);
   T0 = v7;
  }
  si_put_sysprop(VV[35], VV[10], T0);
  {
   cl_object v7package;
   v7package = cl_symbol_package(VV[37]);
   if (Null(v7package)){
    goto L70;
   }
   if (Null(si_package_locked_p(v7package))){
    goto L70;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L70;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[15], ECL_SYM("PACKAGE",1321), v7package);
  }
L70:;
  {
   cl_object volatile v8;
   v8 = ecl_make_cfun_va((cl_objectfn)LC3133__lambda39_va,ECL_NIL,Cblock,2);
   T0 = v8;
  }
  si_put_sysprop(VV[37], VV[10], T0);
  {
   cl_object v8package;
   v8package = cl_symbol_package(VV[39]);
   if (Null(v8package)){
    goto L78;
   }
   if (Null(si_package_locked_p(v8package))){
    goto L78;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L78;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[16], ECL_SYM("PACKAGE",1321), v8package);
  }
L78:;
  {
   cl_object volatile v9;
   v9 = ecl_make_cfun_va((cl_objectfn)LC3134__lambda44_va,ECL_NIL,Cblock,2);
   T0 = v9;
  }
  si_put_sysprop(VV[39], VV[10], T0);
  {
   cl_object v9package;
   v9package = cl_symbol_package(VV[41]);
   if (Null(v9package)){
    goto L86;
   }
   if (Null(si_package_locked_p(v9package))){
    goto L86;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L86;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[17], ECL_SYM("PACKAGE",1321), v9package);
  }
L86:;
  {
   cl_object volatile v10;
   v10 = ecl_make_cfun_va((cl_objectfn)LC3135__lambda49_va,ECL_NIL,Cblock,2);
   T0 = v10;
  }
  si_put_sysprop(VV[41], VV[10], T0);
  {
   cl_object v10package;
   v10package = cl_symbol_package(VV[43]);
   if (Null(v10package)){
    goto L94;
   }
   if (Null(si_package_locked_p(v10package))){
    goto L94;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L94;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[18], ECL_SYM("PACKAGE",1321), v10package);
  }
L94:;
  {
   cl_object volatile v11;
   v11 = ecl_make_cfun_va((cl_objectfn)LC3136__lambda54_va,ECL_NIL,Cblock,2);
   T0 = v11;
  }
  si_put_sysprop(VV[43], VV[10], T0);
  {
   cl_object v11package;
   v11package = cl_symbol_package(VV[45]);
   if (Null(v11package)){
    goto L102;
   }
   if (Null(si_package_locked_p(v11package))){
    goto L102;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L102;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[19], ECL_SYM("PACKAGE",1321), v11package);
  }
L102:;
  {
   cl_object volatile v12;
   v12 = ecl_make_cfun_va((cl_objectfn)LC3137__lambda59_va,ECL_NIL,Cblock,2);
   T0 = v12;
  }
  si_put_sysprop(VV[45], VV[10], T0);
  {
   cl_object v12package;
   v12package = cl_symbol_package(VV[47]);
   if (Null(v12package)){
    goto L110;
   }
   if (Null(si_package_locked_p(v12package))){
    goto L110;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L110;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[20], ECL_SYM("PACKAGE",1321), v12package);
  }
L110:;
  {
   cl_object volatile v13;
   v13 = ecl_make_cfun_va((cl_objectfn)LC3138__lambda64_va,ECL_NIL,Cblock,2);
   T0 = v13;
  }
  si_put_sysprop(VV[47], VV[10], T0);
  {
   cl_object v13package;
   v13package = cl_symbol_package(VV[49]);
   if (Null(v13package)){
    goto L118;
   }
   if (Null(si_package_locked_p(v13package))){
    goto L118;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L118;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[21], ECL_SYM("PACKAGE",1321), v13package);
  }
L118:;
  {
   cl_object volatile v14;
   v14 = ecl_make_cfun_va((cl_objectfn)LC3139__lambda69_va,ECL_NIL,Cblock,2);
   T0 = v14;
  }
  si_put_sysprop(VV[49], VV[10], T0);
  {
   cl_object v14package;
   v14package = cl_symbol_package(VV[51]);
   if (Null(v14package)){
    goto L126;
   }
   if (Null(si_package_locked_p(v14package))){
    goto L126;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L126;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[22], ECL_SYM("PACKAGE",1321), v14package);
  }
L126:;
  {
   cl_object volatile v15;
   v15 = ecl_make_cfun_va((cl_objectfn)LC3140__lambda74_va,ECL_NIL,Cblock,2);
   T0 = v15;
  }
  si_put_sysprop(VV[51], VV[10], T0);
  {
   cl_object v15package;
   v15package = cl_symbol_package(VV[53]);
   if (Null(v15package)){
    goto L134;
   }
   if (Null(si_package_locked_p(v15package))){
    goto L134;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L134;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[23], ECL_SYM("PACKAGE",1321), v15package);
  }
L134:;
  {
   cl_object volatile v16;
   v16 = ecl_make_cfun_va((cl_objectfn)LC3141__lambda79_va,ECL_NIL,Cblock,2);
   T0 = v16;
  }
  si_put_sysprop(VV[53], VV[10], T0);
  {
   cl_object v16package;
   v16package = cl_symbol_package(VV[55]);
   if (Null(v16package)){
    goto L142;
   }
   if (Null(si_package_locked_p(v16package))){
    goto L142;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L142;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[24], ECL_SYM("PACKAGE",1321), v16package);
  }
L142:;
  {
   cl_object volatile v17;
   v17 = ecl_make_cfun_va((cl_objectfn)LC3142__lambda84_va,ECL_NIL,Cblock,2);
   T0 = v17;
  }
  si_put_sysprop(VV[55], VV[10], T0);
  {
   cl_object v17package;
   v17package = cl_symbol_package(VV[57]);
   if (Null(v17package)){
    goto L150;
   }
   if (Null(si_package_locked_p(v17package))){
    goto L150;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L150;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[25], ECL_SYM("PACKAGE",1321), v17package);
  }
L150:;
  {
   cl_object volatile v18;
   v18 = ecl_make_cfun_va((cl_objectfn)LC3143__lambda89_va,ECL_NIL,Cblock,2);
   T0 = v18;
  }
  si_put_sysprop(VV[57], VV[10], T0);
  {
   cl_object v18package;
   v18package = cl_symbol_package(VV[59]);
   if (Null(v18package)){
    goto L158;
   }
   if (Null(si_package_locked_p(v18package))){
    goto L158;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L158;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[26], ECL_SYM("PACKAGE",1321), v18package);
  }
L158:;
  {
   cl_object volatile v19;
   v19 = ecl_make_cfun_va((cl_objectfn)LC3144__lambda94_va,ECL_NIL,Cblock,2);
   T0 = v19;
  }
  si_put_sysprop(VV[59], VV[10], T0);
  ecl_cmp_defun(VV[186]);                         /*  PRINT-VAR               */
  si_define_structure(VV[63], _ecl_static_3, ECL_NIL, ECL_NIL, VVtemp[27], VVtemp[28], VV[64], VV[1], ECL_NIL, ECL_NIL, VVtemp[29], ecl_make_int8_t(32), ECL_NIL, ECL_NIL, VV[65]);
  VV[71]=cl_find_class(1, VV[63]);
  ecl_cmp_defun(VV[187]);                         /*  MAKE-FUN                */
  {
   cl_object v19package;
   v19package = cl_symbol_package(VV[73]);
   if (Null(v19package)){
    goto L177;
   }
   if (Null(si_package_locked_p(v19package))){
    goto L177;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L177;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[30], ECL_SYM("PACKAGE",1321), v19package);
  }
L177:;
  {
   cl_object volatile v20;
   v20 = ecl_make_cfun_va((cl_objectfn)LC3147__lambda101_va,ECL_NIL,Cblock,2);
   T0 = v20;
  }
  si_put_sysprop(VV[73], VV[10], T0);
  {
   cl_object v20package;
   v20package = cl_symbol_package(VV[75]);
   if (Null(v20package)){
    goto L185;
   }
   if (Null(si_package_locked_p(v20package))){
    goto L185;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L185;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[31], ECL_SYM("PACKAGE",1321), v20package);
  }
L185:;
  {
   cl_object volatile v21;
   v21 = ecl_make_cfun_va((cl_objectfn)LC3148__lambda106_va,ECL_NIL,Cblock,2);
   T0 = v21;
  }
  si_put_sysprop(VV[75], VV[10], T0);
  {
   cl_object v21package;
   v21package = cl_symbol_package(VV[77]);
   if (Null(v21package)){
    goto L193;
   }
   if (Null(si_package_locked_p(v21package))){
    goto L193;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L193;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[32], ECL_SYM("PACKAGE",1321), v21package);
  }
L193:;
  {
   cl_object volatile v22;
   v22 = ecl_make_cfun_va((cl_objectfn)LC3149__lambda111_va,ECL_NIL,Cblock,2);
   T0 = v22;
  }
  si_put_sysprop(VV[77], VV[10], T0);
  {
   cl_object v22package;
   v22package = cl_symbol_package(VV[79]);
   if (Null(v22package)){
    goto L201;
   }
   if (Null(si_package_locked_p(v22package))){
    goto L201;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L201;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[33], ECL_SYM("PACKAGE",1321), v22package);
  }
L201:;
  {
   cl_object volatile v23;
   v23 = ecl_make_cfun_va((cl_objectfn)LC3150__lambda116_va,ECL_NIL,Cblock,2);
   T0 = v23;
  }
  si_put_sysprop(VV[79], VV[10], T0);
  {
   cl_object v23package;
   v23package = cl_symbol_package(VV[81]);
   if (Null(v23package)){
    goto L209;
   }
   if (Null(si_package_locked_p(v23package))){
    goto L209;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L209;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[34], ECL_SYM("PACKAGE",1321), v23package);
  }
L209:;
  {
   cl_object volatile v24;
   v24 = ecl_make_cfun_va((cl_objectfn)LC3151__lambda121_va,ECL_NIL,Cblock,2);
   T0 = v24;
  }
  si_put_sysprop(VV[81], VV[10], T0);
  {
   cl_object v24package;
   v24package = cl_symbol_package(VV[83]);
   if (Null(v24package)){
    goto L217;
   }
   if (Null(si_package_locked_p(v24package))){
    goto L217;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L217;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[35], ECL_SYM("PACKAGE",1321), v24package);
  }
L217:;
  {
   cl_object volatile v25;
   v25 = ecl_make_cfun_va((cl_objectfn)LC3152__lambda126_va,ECL_NIL,Cblock,2);
   T0 = v25;
  }
  si_put_sysprop(VV[83], VV[10], T0);
  {
   cl_object v25package;
   v25package = cl_symbol_package(VV[85]);
   if (Null(v25package)){
    goto L225;
   }
   if (Null(si_package_locked_p(v25package))){
    goto L225;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L225;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[36], ECL_SYM("PACKAGE",1321), v25package);
  }
L225:;
  {
   cl_object volatile v26;
   v26 = ecl_make_cfun_va((cl_objectfn)LC3153__lambda131_va,ECL_NIL,Cblock,2);
   T0 = v26;
  }
  si_put_sysprop(VV[85], VV[10], T0);
  {
   cl_object v26package;
   v26package = cl_symbol_package(VV[87]);
   if (Null(v26package)){
    goto L233;
   }
   if (Null(si_package_locked_p(v26package))){
    goto L233;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L233;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[37], ECL_SYM("PACKAGE",1321), v26package);
  }
L233:;
  {
   cl_object volatile v27;
   v27 = ecl_make_cfun_va((cl_objectfn)LC3154__lambda136_va,ECL_NIL,Cblock,2);
   T0 = v27;
  }
  si_put_sysprop(VV[87], VV[10], T0);
  {
   cl_object v27package;
   v27package = cl_symbol_package(VV[89]);
   if (Null(v27package)){
    goto L241;
   }
   if (Null(si_package_locked_p(v27package))){
    goto L241;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L241;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[38], ECL_SYM("PACKAGE",1321), v27package);
  }
L241:;
  {
   cl_object volatile v28;
   v28 = ecl_make_cfun_va((cl_objectfn)LC3155__lambda141_va,ECL_NIL,Cblock,2);
   T0 = v28;
  }
  si_put_sysprop(VV[89], VV[10], T0);
  {
   cl_object v28package;
   v28package = cl_symbol_package(VV[91]);
   if (Null(v28package)){
    goto L249;
   }
   if (Null(si_package_locked_p(v28package))){
    goto L249;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L249;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[39], ECL_SYM("PACKAGE",1321), v28package);
  }
L249:;
  {
   cl_object volatile v29;
   v29 = ecl_make_cfun_va((cl_objectfn)LC3156__lambda146_va,ECL_NIL,Cblock,2);
   T0 = v29;
  }
  si_put_sysprop(VV[91], VV[10], T0);
  {
   cl_object v29package;
   v29package = cl_symbol_package(VV[93]);
   if (Null(v29package)){
    goto L257;
   }
   if (Null(si_package_locked_p(v29package))){
    goto L257;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L257;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[40], ECL_SYM("PACKAGE",1321), v29package);
  }
L257:;
  {
   cl_object volatile v30;
   v30 = ecl_make_cfun_va((cl_objectfn)LC3157__lambda151_va,ECL_NIL,Cblock,2);
   T0 = v30;
  }
  si_put_sysprop(VV[93], VV[10], T0);
  {
   cl_object v30package;
   v30package = cl_symbol_package(VV[95]);
   if (Null(v30package)){
    goto L265;
   }
   if (Null(si_package_locked_p(v30package))){
    goto L265;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L265;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[41], ECL_SYM("PACKAGE",1321), v30package);
  }
L265:;
  {
   cl_object volatile v31;
   v31 = ecl_make_cfun_va((cl_objectfn)LC3158__lambda156_va,ECL_NIL,Cblock,2);
   T0 = v31;
  }
  si_put_sysprop(VV[95], VV[10], T0);
  {
   cl_object v31package;
   v31package = cl_symbol_package(VV[97]);
   if (Null(v31package)){
    goto L273;
   }
   if (Null(si_package_locked_p(v31package))){
    goto L273;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L273;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[42], ECL_SYM("PACKAGE",1321), v31package);
  }
L273:;
  {
   cl_object volatile v32;
   v32 = ecl_make_cfun_va((cl_objectfn)LC3159__lambda161_va,ECL_NIL,Cblock,2);
   T0 = v32;
  }
  si_put_sysprop(VV[97], VV[10], T0);
  {
   cl_object v32package;
   v32package = cl_symbol_package(VV[99]);
   if (Null(v32package)){
    goto L281;
   }
   if (Null(si_package_locked_p(v32package))){
    goto L281;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L281;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[43], ECL_SYM("PACKAGE",1321), v32package);
  }
L281:;
  {
   cl_object volatile v33;
   v33 = ecl_make_cfun_va((cl_objectfn)LC3160__lambda166_va,ECL_NIL,Cblock,2);
   T0 = v33;
  }
  si_put_sysprop(VV[99], VV[10], T0);
  {
   cl_object v33package;
   v33package = cl_symbol_package(VV[101]);
   if (Null(v33package)){
    goto L289;
   }
   if (Null(si_package_locked_p(v33package))){
    goto L289;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L289;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[44], ECL_SYM("PACKAGE",1321), v33package);
  }
L289:;
  {
   cl_object volatile v34;
   v34 = ecl_make_cfun_va((cl_objectfn)LC3161__lambda171_va,ECL_NIL,Cblock,2);
   T0 = v34;
  }
  si_put_sysprop(VV[101], VV[10], T0);
  {
   cl_object v34package;
   v34package = cl_symbol_package(VV[103]);
   if (Null(v34package)){
    goto L297;
   }
   if (Null(si_package_locked_p(v34package))){
    goto L297;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L297;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[45], ECL_SYM("PACKAGE",1321), v34package);
  }
L297:;
  {
   cl_object volatile v35;
   v35 = ecl_make_cfun_va((cl_objectfn)LC3162__lambda176_va,ECL_NIL,Cblock,2);
   T0 = v35;
  }
  si_put_sysprop(VV[103], VV[10], T0);
  {
   cl_object v35package;
   v35package = cl_symbol_package(VV[105]);
   if (Null(v35package)){
    goto L305;
   }
   if (Null(si_package_locked_p(v35package))){
    goto L305;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L305;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[46], ECL_SYM("PACKAGE",1321), v35package);
  }
L305:;
  {
   cl_object volatile v36;
   v36 = ecl_make_cfun_va((cl_objectfn)LC3163__lambda181_va,ECL_NIL,Cblock,2);
   T0 = v36;
  }
  si_put_sysprop(VV[105], VV[10], T0);
  {
   cl_object v36package;
   v36package = cl_symbol_package(VV[107]);
   if (Null(v36package)){
    goto L313;
   }
   if (Null(si_package_locked_p(v36package))){
    goto L313;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L313;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[47], ECL_SYM("PACKAGE",1321), v36package);
  }
L313:;
  {
   cl_object volatile v37;
   v37 = ecl_make_cfun_va((cl_objectfn)LC3164__lambda186_va,ECL_NIL,Cblock,2);
   T0 = v37;
  }
  si_put_sysprop(VV[107], VV[10], T0);
  {
   cl_object v37package;
   v37package = cl_symbol_package(VV[109]);
   if (Null(v37package)){
    goto L321;
   }
   if (Null(si_package_locked_p(v37package))){
    goto L321;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L321;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[48], ECL_SYM("PACKAGE",1321), v37package);
  }
L321:;
  {
   cl_object volatile v38;
   v38 = ecl_make_cfun_va((cl_objectfn)LC3165__lambda191_va,ECL_NIL,Cblock,2);
   T0 = v38;
  }
  si_put_sysprop(VV[109], VV[10], T0);
  {
   cl_object v38package;
   v38package = cl_symbol_package(VV[111]);
   if (Null(v38package)){
    goto L329;
   }
   if (Null(si_package_locked_p(v38package))){
    goto L329;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L329;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[49], ECL_SYM("PACKAGE",1321), v38package);
  }
L329:;
  {
   cl_object volatile v39;
   v39 = ecl_make_cfun_va((cl_objectfn)LC3166__lambda196_va,ECL_NIL,Cblock,2);
   T0 = v39;
  }
  si_put_sysprop(VV[111], VV[10], T0);
  {
   cl_object v39package;
   v39package = cl_symbol_package(VV[113]);
   if (Null(v39package)){
    goto L337;
   }
   if (Null(si_package_locked_p(v39package))){
    goto L337;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L337;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[50], ECL_SYM("PACKAGE",1321), v39package);
  }
L337:;
  {
   cl_object volatile v40;
   v40 = ecl_make_cfun_va((cl_objectfn)LC3167__lambda201_va,ECL_NIL,Cblock,2);
   T0 = v40;
  }
  si_put_sysprop(VV[113], VV[10], T0);
  {
   cl_object v40package;
   v40package = cl_symbol_package(VV[115]);
   if (Null(v40package)){
    goto L345;
   }
   if (Null(si_package_locked_p(v40package))){
    goto L345;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L345;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[51], ECL_SYM("PACKAGE",1321), v40package);
  }
L345:;
  {
   cl_object volatile v41;
   v41 = ecl_make_cfun_va((cl_objectfn)LC3168__lambda206_va,ECL_NIL,Cblock,2);
   T0 = v41;
  }
  si_put_sysprop(VV[115], VV[10], T0);
  {
   cl_object v41package;
   v41package = cl_symbol_package(VV[117]);
   if (Null(v41package)){
    goto L353;
   }
   if (Null(si_package_locked_p(v41package))){
    goto L353;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L353;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[52], ECL_SYM("PACKAGE",1321), v41package);
  }
L353:;
  {
   cl_object volatile v42;
   v42 = ecl_make_cfun_va((cl_objectfn)LC3169__lambda211_va,ECL_NIL,Cblock,2);
   T0 = v42;
  }
  si_put_sysprop(VV[117], VV[10], T0);
  {
   cl_object v42package;
   v42package = cl_symbol_package(VV[119]);
   if (Null(v42package)){
    goto L361;
   }
   if (Null(si_package_locked_p(v42package))){
    goto L361;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L361;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[53], ECL_SYM("PACKAGE",1321), v42package);
  }
L361:;
  {
   cl_object volatile v43;
   v43 = ecl_make_cfun_va((cl_objectfn)LC3170__lambda216_va,ECL_NIL,Cblock,2);
   T0 = v43;
  }
  si_put_sysprop(VV[119], VV[10], T0);
  {
   cl_object v43package;
   v43package = cl_symbol_package(VV[121]);
   if (Null(v43package)){
    goto L369;
   }
   if (Null(si_package_locked_p(v43package))){
    goto L369;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L369;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[54], ECL_SYM("PACKAGE",1321), v43package);
  }
L369:;
  {
   cl_object volatile v44;
   v44 = ecl_make_cfun_va((cl_objectfn)LC3171__lambda221_va,ECL_NIL,Cblock,2);
   T0 = v44;
  }
  si_put_sysprop(VV[121], VV[10], T0);
  {
   cl_object v44package;
   v44package = cl_symbol_package(VV[123]);
   if (Null(v44package)){
    goto L377;
   }
   if (Null(si_package_locked_p(v44package))){
    goto L377;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L377;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[55], ECL_SYM("PACKAGE",1321), v44package);
  }
L377:;
  {
   cl_object volatile v45;
   v45 = ecl_make_cfun_va((cl_objectfn)LC3172__lambda226_va,ECL_NIL,Cblock,2);
   T0 = v45;
  }
  si_put_sysprop(VV[123], VV[10], T0);
  {
   cl_object v45package;
   v45package = cl_symbol_package(VV[125]);
   if (Null(v45package)){
    goto L385;
   }
   if (Null(si_package_locked_p(v45package))){
    goto L385;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L385;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[56], ECL_SYM("PACKAGE",1321), v45package);
  }
L385:;
  {
   cl_object volatile v46;
   v46 = ecl_make_cfun_va((cl_objectfn)LC3173__lambda231_va,ECL_NIL,Cblock,2);
   T0 = v46;
  }
  si_put_sysprop(VV[125], VV[10], T0);
  {
   cl_object v46package;
   v46package = cl_symbol_package(VV[127]);
   if (Null(v46package)){
    goto L393;
   }
   if (Null(si_package_locked_p(v46package))){
    goto L393;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L393;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[57], ECL_SYM("PACKAGE",1321), v46package);
  }
L393:;
  {
   cl_object volatile v47;
   v47 = ecl_make_cfun_va((cl_objectfn)LC3174__lambda236_va,ECL_NIL,Cblock,2);
   T0 = v47;
  }
  si_put_sysprop(VV[127], VV[10], T0);
  {
   cl_object v47package;
   v47package = cl_symbol_package(VV[129]);
   if (Null(v47package)){
    goto L401;
   }
   if (Null(si_package_locked_p(v47package))){
    goto L401;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L401;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[58], ECL_SYM("PACKAGE",1321), v47package);
  }
L401:;
  {
   cl_object volatile v48;
   v48 = ecl_make_cfun_va((cl_objectfn)LC3175__lambda241_va,ECL_NIL,Cblock,2);
   T0 = v48;
  }
  si_put_sysprop(VV[129], VV[10], T0);
  {
   cl_object v48package;
   v48package = cl_symbol_package(VV[131]);
   if (Null(v48package)){
    goto L409;
   }
   if (Null(si_package_locked_p(v48package))){
    goto L409;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L409;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[59], ECL_SYM("PACKAGE",1321), v48package);
  }
L409:;
  {
   cl_object volatile v49;
   v49 = ecl_make_cfun_va((cl_objectfn)LC3176__lambda246_va,ECL_NIL,Cblock,2);
   T0 = v49;
  }
  si_put_sysprop(VV[131], VV[10], T0);
  {
   cl_object v49package;
   v49package = cl_symbol_package(VV[133]);
   if (Null(v49package)){
    goto L417;
   }
   if (Null(si_package_locked_p(v49package))){
    goto L417;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L417;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[60], ECL_SYM("PACKAGE",1321), v49package);
  }
L417:;
  {
   cl_object volatile v50;
   v50 = ecl_make_cfun_va((cl_objectfn)LC3177__lambda251_va,ECL_NIL,Cblock,2);
   T0 = v50;
  }
  si_put_sysprop(VV[133], VV[10], T0);
  {
   cl_object v50package;
   v50package = cl_symbol_package(VV[135]);
   if (Null(v50package)){
    goto L425;
   }
   if (Null(si_package_locked_p(v50package))){
    goto L425;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L425;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[61], ECL_SYM("PACKAGE",1321), v50package);
  }
L425:;
  {
   cl_object volatile v51;
   v51 = ecl_make_cfun_va((cl_objectfn)LC3178__lambda256_va,ECL_NIL,Cblock,2);
   T0 = v51;
  }
  si_put_sysprop(VV[135], VV[10], T0);
  si_define_structure(VV[137], _ecl_static_4, ECL_NIL, ECL_NIL, VVtemp[62], VVtemp[63], VV[138], VV[1], ECL_NIL, ECL_NIL, VVtemp[64], ecl_make_int8_t(9), ECL_NIL, ECL_NIL, VV[139]);
  VV[141]=cl_find_class(1, VV[137]);
  ecl_cmp_defun(VV[188]);                         /*  MAKE-BLK                */
  {
   cl_object v51package;
   v51package = cl_symbol_package(VV[143]);
   if (Null(v51package)){
    goto L441;
   }
   if (Null(si_package_locked_p(v51package))){
    goto L441;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L441;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[65], ECL_SYM("PACKAGE",1321), v51package);
  }
L441:;
  {
   cl_object volatile v52;
   v52 = ecl_make_cfun_va((cl_objectfn)LC3180__lambda262_va,ECL_NIL,Cblock,2);
   T0 = v52;
  }
  si_put_sysprop(VV[143], VV[10], T0);
  {
   cl_object v52package;
   v52package = cl_symbol_package(VV[145]);
   if (Null(v52package)){
    goto L449;
   }
   if (Null(si_package_locked_p(v52package))){
    goto L449;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L449;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[66], ECL_SYM("PACKAGE",1321), v52package);
  }
L449:;
  {
   cl_object volatile v53;
   v53 = ecl_make_cfun_va((cl_objectfn)LC3181__lambda267_va,ECL_NIL,Cblock,2);
   T0 = v53;
  }
  si_put_sysprop(VV[145], VV[10], T0);
  {
   cl_object v53package;
   v53package = cl_symbol_package(VV[147]);
   if (Null(v53package)){
    goto L457;
   }
   if (Null(si_package_locked_p(v53package))){
    goto L457;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L457;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[67], ECL_SYM("PACKAGE",1321), v53package);
  }
L457:;
  {
   cl_object volatile v54;
   v54 = ecl_make_cfun_va((cl_objectfn)LC3182__lambda272_va,ECL_NIL,Cblock,2);
   T0 = v54;
  }
  si_put_sysprop(VV[147], VV[10], T0);
  {
   cl_object v54package;
   v54package = cl_symbol_package(VV[149]);
   if (Null(v54package)){
    goto L465;
   }
   if (Null(si_package_locked_p(v54package))){
    goto L465;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L465;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[68], ECL_SYM("PACKAGE",1321), v54package);
  }
L465:;
  {
   cl_object volatile v55;
   v55 = ecl_make_cfun_va((cl_objectfn)LC3183__lambda277_va,ECL_NIL,Cblock,2);
   T0 = v55;
  }
  si_put_sysprop(VV[149], VV[10], T0);
  {
   cl_object v55package;
   v55package = cl_symbol_package(VV[151]);
   if (Null(v55package)){
    goto L473;
   }
   if (Null(si_package_locked_p(v55package))){
    goto L473;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L473;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[69], ECL_SYM("PACKAGE",1321), v55package);
  }
L473:;
  {
   cl_object volatile v56;
   v56 = ecl_make_cfun_va((cl_objectfn)LC3184__lambda282_va,ECL_NIL,Cblock,2);
   T0 = v56;
  }
  si_put_sysprop(VV[151], VV[10], T0);
  {
   cl_object v56package;
   v56package = cl_symbol_package(VV[153]);
   if (Null(v56package)){
    goto L481;
   }
   if (Null(si_package_locked_p(v56package))){
    goto L481;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L481;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[70], ECL_SYM("PACKAGE",1321), v56package);
  }
L481:;
  {
   cl_object volatile v57;
   v57 = ecl_make_cfun_va((cl_objectfn)LC3185__lambda287_va,ECL_NIL,Cblock,2);
   T0 = v57;
  }
  si_put_sysprop(VV[153], VV[10], T0);
  {
   cl_object v57package;
   v57package = cl_symbol_package(VV[155]);
   if (Null(v57package)){
    goto L489;
   }
   if (Null(si_package_locked_p(v57package))){
    goto L489;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L489;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[71], ECL_SYM("PACKAGE",1321), v57package);
  }
L489:;
  {
   cl_object volatile v58;
   v58 = ecl_make_cfun_va((cl_objectfn)LC3186__lambda292_va,ECL_NIL,Cblock,2);
   T0 = v58;
  }
  si_put_sysprop(VV[155], VV[10], T0);
  {
   cl_object v58package;
   v58package = cl_symbol_package(VV[157]);
   if (Null(v58package)){
    goto L497;
   }
   if (Null(si_package_locked_p(v58package))){
    goto L497;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L497;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[72], ECL_SYM("PACKAGE",1321), v58package);
  }
L497:;
  {
   cl_object volatile v59;
   v59 = ecl_make_cfun_va((cl_objectfn)LC3187__lambda297_va,ECL_NIL,Cblock,2);
   T0 = v59;
  }
  si_put_sysprop(VV[157], VV[10], T0);
  {
   cl_object v59package;
   v59package = cl_symbol_package(VV[159]);
   if (Null(v59package)){
    goto L505;
   }
   if (Null(si_package_locked_p(v59package))){
    goto L505;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L505;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[73], ECL_SYM("PACKAGE",1321), v59package);
  }
L505:;
  {
   cl_object volatile v60;
   v60 = ecl_make_cfun_va((cl_objectfn)LC3188__lambda302_va,ECL_NIL,Cblock,2);
   T0 = v60;
  }
  si_put_sysprop(VV[159], VV[10], T0);
  si_define_structure(VV[161], _ecl_static_5, ECL_NIL, ECL_NIL, VVtemp[74], VVtemp[75], VV[162], VV[1], ECL_NIL, ECL_NIL, VVtemp[76], ecl_make_int8_t(8), ECL_NIL, ECL_NIL, VV[163]);
  VV[165]=cl_find_class(1, VV[161]);
  ecl_cmp_defun(VV[189]);                         /*  MAKE-TAG                */
  {
   cl_object v60package;
   v60package = cl_symbol_package(VV[167]);
   if (Null(v60package)){
    goto L521;
   }
   if (Null(si_package_locked_p(v60package))){
    goto L521;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L521;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[77], ECL_SYM("PACKAGE",1321), v60package);
  }
L521:;
  {
   cl_object volatile v61;
   v61 = ecl_make_cfun_va((cl_objectfn)LC3190__lambda308_va,ECL_NIL,Cblock,2);
   T0 = v61;
  }
  si_put_sysprop(VV[167], VV[10], T0);
  {
   cl_object v61package;
   v61package = cl_symbol_package(VV[169]);
   if (Null(v61package)){
    goto L529;
   }
   if (Null(si_package_locked_p(v61package))){
    goto L529;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L529;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[78], ECL_SYM("PACKAGE",1321), v61package);
  }
L529:;
  {
   cl_object volatile v62;
   v62 = ecl_make_cfun_va((cl_objectfn)LC3191__lambda313_va,ECL_NIL,Cblock,2);
   T0 = v62;
  }
  si_put_sysprop(VV[169], VV[10], T0);
  {
   cl_object v62package;
   v62package = cl_symbol_package(VV[171]);
   if (Null(v62package)){
    goto L537;
   }
   if (Null(si_package_locked_p(v62package))){
    goto L537;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L537;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[79], ECL_SYM("PACKAGE",1321), v62package);
  }
L537:;
  {
   cl_object volatile v63;
   v63 = ecl_make_cfun_va((cl_objectfn)LC3192__lambda318_va,ECL_NIL,Cblock,2);
   T0 = v63;
  }
  si_put_sysprop(VV[171], VV[10], T0);
  {
   cl_object v63package;
   v63package = cl_symbol_package(VV[173]);
   if (Null(v63package)){
    goto L545;
   }
   if (Null(si_package_locked_p(v63package))){
    goto L545;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L545;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[80], ECL_SYM("PACKAGE",1321), v63package);
  }
L545:;
  {
   cl_object volatile v64;
   v64 = ecl_make_cfun_va((cl_objectfn)LC3193__lambda323_va,ECL_NIL,Cblock,2);
   T0 = v64;
  }
  si_put_sysprop(VV[173], VV[10], T0);
  {
   cl_object v64package;
   v64package = cl_symbol_package(VV[175]);
   if (Null(v64package)){
    goto L553;
   }
   if (Null(si_package_locked_p(v64package))){
    goto L553;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L553;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[81], ECL_SYM("PACKAGE",1321), v64package);
  }
L553:;
  {
   cl_object volatile v65;
   v65 = ecl_make_cfun_va((cl_objectfn)LC3194__lambda328_va,ECL_NIL,Cblock,2);
   T0 = v65;
  }
  si_put_sysprop(VV[175], VV[10], T0);
  {
   cl_object v65package;
   v65package = cl_symbol_package(VV[177]);
   if (Null(v65package)){
    goto L561;
   }
   if (Null(si_package_locked_p(v65package))){
    goto L561;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L561;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[82], ECL_SYM("PACKAGE",1321), v65package);
  }
L561:;
  {
   cl_object volatile v66;
   v66 = ecl_make_cfun_va((cl_objectfn)LC3195__lambda333_va,ECL_NIL,Cblock,2);
   T0 = v66;
  }
  si_put_sysprop(VV[177], VV[10], T0);
  {
   cl_object v66package;
   v66package = cl_symbol_package(VV[179]);
   if (Null(v66package)){
    goto L569;
   }
   if (Null(si_package_locked_p(v66package))){
    goto L569;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L569;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[83], ECL_SYM("PACKAGE",1321), v66package);
  }
L569:;
  {
   cl_object volatile v67;
   v67 = ecl_make_cfun_va((cl_objectfn)LC3196__lambda338_va,ECL_NIL,Cblock,2);
   T0 = v67;
  }
  si_put_sysprop(VV[179], VV[10], T0);
  {
   cl_object v67package;
   v67package = cl_symbol_package(VV[181]);
   if (Null(v67package)){
    goto L577;
   }
   if (Null(si_package_locked_p(v67package))){
    goto L577;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L577;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[84], ECL_SYM("PACKAGE",1321), v67package);
  }
L577:;
  {
   cl_object volatile v68;
   v68 = ecl_make_cfun_va((cl_objectfn)LC3197__lambda343_va,ECL_NIL,Cblock,2);
   T0 = v68;
  }
  si_put_sysprop(VV[181], VV[10], T0);
 }
}
